@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# (C) 2000 David Leadbeater (cgiirc@dgl.cx)
+# (C) 2000 David Leadbeater (http://contact.dgl.cx/)
 # cgi-irc comes with ABSOLUTELY NO WARRANTY
 # This is free software, and you are welcome to redistribute it
 # under certain conditions; read the file COPYING for details
@@ -14,8 +14,13 @@ use strict;
 use Socket;
 my($input,$output);
 
-print "Type the Hex IP to decode into a normal IP address\n";
-$input=<>;
+if($#ARGV >= $[) {
+	$input = shift;
+} else {
+	print "Type the Hex IP to decode into a normal IP address\n";
+	$input=<>;
+}
+
 $input =~ s/[^a-z0-9]//gi;
 
 $output = pack "H*", $input;
