@@ -1,4 +1,4 @@
-# $Id: RawCommands.pm,v 1.25 2003/10/29 12:28:35 dgl Exp $
+# $Id: RawCommands.pm,v 1.30 2006/04/30 13:10:37 dgl Exp $
 package IRC::RawCommands;
 use strict;
 
@@ -79,7 +79,7 @@ my %raw = (
       my $action = substr($mode,0,1) || '+';
 	  my $num = 3;
       
-	  if(is_vaild_nickname($to)) {
+	  if($self->is_nickname($to)) {
 	     return unless $to eq $self->{nick};
 		 for(split //, $mode) {
 		    if(/([+-])/) {
@@ -173,10 +173,11 @@ my %raw = (
 		  $target =~ s/^[+@%]//g;
 		  $self->{event}->handle('message special', _info($target, 2),
 		     $params->{nick}, $params->{host}, $to, $params->{text});
-	  }elsif(is_vaild_server($params->{nick})) {
+	  }elsif(is_valid_server($params->{nick})) {
 	     $self->{event}->handle('message server', _info($to, 2),
 			 $params->{nick}, $params->{host}, $params->{text});
 	  }else{
+		  #return unless $self->find_nick_channels($params->{nick});
 	     $self->{event}->handle('message private', _info($params->{nick}, 3, 1),
 			 $params->{nick}, $params->{host}, $params->{text});
 	  }
@@ -195,7 +196,7 @@ my %raw = (
 		  $target =~ s/^[+@%]+//;
 		  $self->{event}->handle('notice special', _info($target, 1),
 		     $params->{nick}, $params->{host}, $to, $params->{text});
-	  }elsif(is_vaild_server($params->{nick})) {
+	  }elsif(is_valid_server($params->{nick})) {
 	     $self->{event}->handle('notice server', _info('Status', 1),
 			 $params->{nick}, $params->{host}, $params->{text});
 	  }else{
@@ -325,7 +326,8 @@ my %raw = (
    },
    317 => sub { # RPL_WHOISIDLE
       my($event,$self,$params) = @_;
-	  $self->{event}->handle('reply whois idle', _info($params->{params}->[2], 1), $params->{params}->[3], scalar gmtime($params->{params}->[4]), $params->{text});
+      my $time = ::format_parse($::format->{time}, {}, [gmtime $params->{params}->[3]]);
+	  $self->{event}->handle('reply whois idle', _info($params->{params}->[2], 1), $time, scalar gmtime($params->{params}->[4]), $params->{text});
    },
    319 => sub { # RPL_WHOISCHANNELS
       my($event,$self,$params) = @_;
